# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.dialogflow import gapic_version as package_version

__version__ = package_version.__version__


from .services.agents import AgentsAsyncClient, AgentsClient
from .services.answer_records import AnswerRecordsAsyncClient, AnswerRecordsClient
from .services.contexts import ContextsAsyncClient, ContextsClient
from .services.conversation_profiles import (
    ConversationProfilesAsyncClient,
    ConversationProfilesClient,
)
from .services.conversations import ConversationsAsyncClient, ConversationsClient
from .services.documents import DocumentsAsyncClient, DocumentsClient
from .services.entity_types import EntityTypesAsyncClient, EntityTypesClient
from .services.environments import EnvironmentsAsyncClient, EnvironmentsClient
from .services.fulfillments import FulfillmentsAsyncClient, FulfillmentsClient
from .services.intents import IntentsAsyncClient, IntentsClient
from .services.knowledge_bases import KnowledgeBasesAsyncClient, KnowledgeBasesClient
from .services.participants import ParticipantsAsyncClient, ParticipantsClient
from .services.session_entity_types import (
    SessionEntityTypesAsyncClient,
    SessionEntityTypesClient,
)
from .services.sessions import SessionsAsyncClient, SessionsClient
from .services.versions import VersionsAsyncClient, VersionsClient
from .types.agent import (
    Agent,
    DeleteAgentRequest,
    ExportAgentRequest,
    ExportAgentResponse,
    GetAgentRequest,
    GetValidationResultRequest,
    ImportAgentRequest,
    RestoreAgentRequest,
    SearchAgentsRequest,
    SearchAgentsResponse,
    SetAgentRequest,
    SubAgent,
    TrainAgentRequest,
)
from .types.answer_record import (
    AgentAssistantFeedback,
    AgentAssistantRecord,
    AnswerFeedback,
    AnswerRecord,
    GetAnswerRecordRequest,
    ListAnswerRecordsRequest,
    ListAnswerRecordsResponse,
    UpdateAnswerRecordRequest,
)
from .types.audio_config import (
    AudioEncoding,
    InputAudioConfig,
    OutputAudioConfig,
    OutputAudioEncoding,
    SpeechContext,
    SpeechModelVariant,
    SpeechToTextConfig,
    SpeechWordInfo,
    SsmlVoiceGender,
    SynthesizeSpeechConfig,
    TelephonyDtmf,
    TelephonyDtmfEvents,
    VoiceSelectionParams,
)
from .types.context import (
    Context,
    CreateContextRequest,
    DeleteAllContextsRequest,
    DeleteContextRequest,
    GetContextRequest,
    ListContextsRequest,
    ListContextsResponse,
    UpdateContextRequest,
)
from .types.conversation import (
    BatchCreateMessagesRequest,
    BatchCreateMessagesResponse,
    CompleteConversationRequest,
    Conversation,
    ConversationPhoneNumber,
    CreateConversationRequest,
    CreateMessageRequest,
    GetConversationRequest,
    ListConversationsRequest,
    ListConversationsResponse,
    ListMessagesRequest,
    ListMessagesResponse,
    SuggestConversationSummaryRequest,
    SuggestConversationSummaryResponse,
)
from .types.conversation_event import ConversationEvent
from .types.conversation_profile import (
    AutomatedAgentConfig,
    ClearSuggestionFeatureConfigOperationMetadata,
    ClearSuggestionFeatureConfigRequest,
    ConversationProfile,
    CreateConversationProfileRequest,
    DeleteConversationProfileRequest,
    GetConversationProfileRequest,
    HumanAgentAssistantConfig,
    HumanAgentHandoffConfig,
    ListConversationProfilesRequest,
    ListConversationProfilesResponse,
    LoggingConfig,
    NotificationConfig,
    SetSuggestionFeatureConfigOperationMetadata,
    SetSuggestionFeatureConfigRequest,
    UpdateConversationProfileRequest,
)
from .types.document import (
    CreateDocumentRequest,
    DeleteDocumentRequest,
    Document,
    ExportOperationMetadata,
    GetDocumentRequest,
    ImportDocumentsRequest,
    ImportDocumentsResponse,
    ImportDocumentTemplate,
    KnowledgeOperationMetadata,
    ListDocumentsRequest,
    ListDocumentsResponse,
    ReloadDocumentRequest,
    UpdateDocumentRequest,
)
from .types.entity_type import (
    BatchCreateEntitiesRequest,
    BatchDeleteEntitiesRequest,
    BatchDeleteEntityTypesRequest,
    BatchUpdateEntitiesRequest,
    BatchUpdateEntityTypesRequest,
    BatchUpdateEntityTypesResponse,
    CreateEntityTypeRequest,
    DeleteEntityTypeRequest,
    EntityType,
    EntityTypeBatch,
    GetEntityTypeRequest,
    ListEntityTypesRequest,
    ListEntityTypesResponse,
    UpdateEntityTypeRequest,
)
from .types.environment import (
    CreateEnvironmentRequest,
    DeleteEnvironmentRequest,
    Environment,
    EnvironmentHistory,
    GetEnvironmentHistoryRequest,
    GetEnvironmentRequest,
    ListEnvironmentsRequest,
    ListEnvironmentsResponse,
    TextToSpeechSettings,
    UpdateEnvironmentRequest,
)
from .types.fulfillment import (
    Fulfillment,
    GetFulfillmentRequest,
    UpdateFulfillmentRequest,
)
from .types.gcs import GcsDestination, GcsSource, GcsSources
from .types.human_agent_assistant_event import HumanAgentAssistantEvent
from .types.intent import (
    BatchDeleteIntentsRequest,
    BatchUpdateIntentsRequest,
    BatchUpdateIntentsResponse,
    CreateIntentRequest,
    DeleteIntentRequest,
    GetIntentRequest,
    Intent,
    IntentBatch,
    IntentView,
    ListIntentsRequest,
    ListIntentsResponse,
    UpdateIntentRequest,
)
from .types.knowledge_base import (
    CreateKnowledgeBaseRequest,
    DeleteKnowledgeBaseRequest,
    GetKnowledgeBaseRequest,
    KnowledgeBase,
    ListKnowledgeBasesRequest,
    ListKnowledgeBasesResponse,
    UpdateKnowledgeBaseRequest,
)
from .types.participant import (
    AnalyzeContentRequest,
    AnalyzeContentResponse,
    AnnotatedMessagePart,
    ArticleAnswer,
    AssistQueryParameters,
    AudioInput,
    AutomatedAgentReply,
    CompileSuggestionRequest,
    CompileSuggestionResponse,
    CreateParticipantRequest,
    DtmfParameters,
    FaqAnswer,
    GetParticipantRequest,
    InputTextConfig,
    ListParticipantsRequest,
    ListParticipantsResponse,
    ListSuggestionsRequest,
    ListSuggestionsResponse,
    Message,
    MessageAnnotation,
    OutputAudio,
    Participant,
    ResponseMessage,
    SmartReplyAnswer,
    StreamingAnalyzeContentRequest,
    StreamingAnalyzeContentResponse,
    SuggestArticlesRequest,
    SuggestArticlesResponse,
    SuggestFaqAnswersRequest,
    SuggestFaqAnswersResponse,
    Suggestion,
    SuggestionFeature,
    SuggestionResult,
    SuggestSmartRepliesRequest,
    SuggestSmartRepliesResponse,
    UpdateParticipantRequest,
)
from .types.session import (
    DetectIntentRequest,
    DetectIntentResponse,
    EventInput,
    KnowledgeAnswers,
    QueryInput,
    QueryParameters,
    QueryResult,
    Sentiment,
    SentimentAnalysisRequestConfig,
    SentimentAnalysisResult,
    StreamingDetectIntentRequest,
    StreamingDetectIntentResponse,
    StreamingRecognitionResult,
    TextInput,
)
from .types.session_entity_type import (
    CreateSessionEntityTypeRequest,
    DeleteSessionEntityTypeRequest,
    GetSessionEntityTypeRequest,
    ListSessionEntityTypesRequest,
    ListSessionEntityTypesResponse,
    SessionEntityType,
    UpdateSessionEntityTypeRequest,
)
from .types.validation_result import ValidationError, ValidationResult
from .types.version import (
    CreateVersionRequest,
    DeleteVersionRequest,
    GetVersionRequest,
    ListVersionsRequest,
    ListVersionsResponse,
    UpdateVersionRequest,
    Version,
)
from .types.webhook import OriginalDetectIntentRequest, WebhookRequest, WebhookResponse

__all__ = (
    "AgentsAsyncClient",
    "AnswerRecordsAsyncClient",
    "ContextsAsyncClient",
    "ConversationProfilesAsyncClient",
    "ConversationsAsyncClient",
    "DocumentsAsyncClient",
    "EntityTypesAsyncClient",
    "EnvironmentsAsyncClient",
    "FulfillmentsAsyncClient",
    "IntentsAsyncClient",
    "KnowledgeBasesAsyncClient",
    "ParticipantsAsyncClient",
    "SessionEntityTypesAsyncClient",
    "SessionsAsyncClient",
    "VersionsAsyncClient",
    "Agent",
    "AgentAssistantFeedback",
    "AgentAssistantRecord",
    "AgentsClient",
    "AnalyzeContentRequest",
    "AnalyzeContentResponse",
    "AnnotatedMessagePart",
    "AnswerFeedback",
    "AnswerRecord",
    "AnswerRecordsClient",
    "ArticleAnswer",
    "AssistQueryParameters",
    "AudioEncoding",
    "AudioInput",
    "AutomatedAgentConfig",
    "AutomatedAgentReply",
    "BatchCreateEntitiesRequest",
    "BatchCreateMessagesRequest",
    "BatchCreateMessagesResponse",
    "BatchDeleteEntitiesRequest",
    "BatchDeleteEntityTypesRequest",
    "BatchDeleteIntentsRequest",
    "BatchUpdateEntitiesRequest",
    "BatchUpdateEntityTypesRequest",
    "BatchUpdateEntityTypesResponse",
    "BatchUpdateIntentsRequest",
    "BatchUpdateIntentsResponse",
    "ClearSuggestionFeatureConfigOperationMetadata",
    "ClearSuggestionFeatureConfigRequest",
    "CompileSuggestionRequest",
    "CompileSuggestionResponse",
    "CompleteConversationRequest",
    "Context",
    "ContextsClient",
    "Conversation",
    "ConversationEvent",
    "ConversationPhoneNumber",
    "ConversationProfile",
    "ConversationProfilesClient",
    "ConversationsClient",
    "CreateContextRequest",
    "CreateConversationProfileRequest",
    "CreateConversationRequest",
    "CreateDocumentRequest",
    "CreateEntityTypeRequest",
    "CreateEnvironmentRequest",
    "CreateIntentRequest",
    "CreateKnowledgeBaseRequest",
    "CreateMessageRequest",
    "CreateParticipantRequest",
    "CreateSessionEntityTypeRequest",
    "CreateVersionRequest",
    "DeleteAgentRequest",
    "DeleteAllContextsRequest",
    "DeleteContextRequest",
    "DeleteConversationProfileRequest",
    "DeleteDocumentRequest",
    "DeleteEntityTypeRequest",
    "DeleteEnvironmentRequest",
    "DeleteIntentRequest",
    "DeleteKnowledgeBaseRequest",
    "DeleteSessionEntityTypeRequest",
    "DeleteVersionRequest",
    "DetectIntentRequest",
    "DetectIntentResponse",
    "Document",
    "DocumentsClient",
    "DtmfParameters",
    "EntityType",
    "EntityTypeBatch",
    "EntityTypesClient",
    "Environment",
    "EnvironmentHistory",
    "EnvironmentsClient",
    "EventInput",
    "ExportAgentRequest",
    "ExportAgentResponse",
    "ExportOperationMetadata",
    "FaqAnswer",
    "Fulfillment",
    "FulfillmentsClient",
    "GcsDestination",
    "GcsSource",
    "GcsSources",
    "GetAgentRequest",
    "GetAnswerRecordRequest",
    "GetContextRequest",
    "GetConversationProfileRequest",
    "GetConversationRequest",
    "GetDocumentRequest",
    "GetEntityTypeRequest",
    "GetEnvironmentHistoryRequest",
    "GetEnvironmentRequest",
    "GetFulfillmentRequest",
    "GetIntentRequest",
    "GetKnowledgeBaseRequest",
    "GetParticipantRequest",
    "GetSessionEntityTypeRequest",
    "GetValidationResultRequest",
    "GetVersionRequest",
    "HumanAgentAssistantConfig",
    "HumanAgentAssistantEvent",
    "HumanAgentHandoffConfig",
    "ImportAgentRequest",
    "ImportDocumentTemplate",
    "ImportDocumentsRequest",
    "ImportDocumentsResponse",
    "InputAudioConfig",
    "InputTextConfig",
    "Intent",
    "IntentBatch",
    "IntentView",
    "IntentsClient",
    "KnowledgeAnswers",
    "KnowledgeBase",
    "KnowledgeBasesClient",
    "KnowledgeOperationMetadata",
    "ListAnswerRecordsRequest",
    "ListAnswerRecordsResponse",
    "ListContextsRequest",
    "ListContextsResponse",
    "ListConversationProfilesRequest",
    "ListConversationProfilesResponse",
    "ListConversationsRequest",
    "ListConversationsResponse",
    "ListDocumentsRequest",
    "ListDocumentsResponse",
    "ListEntityTypesRequest",
    "ListEntityTypesResponse",
    "ListEnvironmentsRequest",
    "ListEnvironmentsResponse",
    "ListIntentsRequest",
    "ListIntentsResponse",
    "ListKnowledgeBasesRequest",
    "ListKnowledgeBasesResponse",
    "ListMessagesRequest",
    "ListMessagesResponse",
    "ListParticipantsRequest",
    "ListParticipantsResponse",
    "ListSessionEntityTypesRequest",
    "ListSessionEntityTypesResponse",
    "ListSuggestionsRequest",
    "ListSuggestionsResponse",
    "ListVersionsRequest",
    "ListVersionsResponse",
    "LoggingConfig",
    "Message",
    "MessageAnnotation",
    "NotificationConfig",
    "OriginalDetectIntentRequest",
    "OutputAudio",
    "OutputAudioConfig",
    "OutputAudioEncoding",
    "Participant",
    "ParticipantsClient",
    "QueryInput",
    "QueryParameters",
    "QueryResult",
    "ReloadDocumentRequest",
    "ResponseMessage",
    "RestoreAgentRequest",
    "SearchAgentsRequest",
    "SearchAgentsResponse",
    "Sentiment",
    "SentimentAnalysisRequestConfig",
    "SentimentAnalysisResult",
    "SessionEntityType",
    "SessionEntityTypesClient",
    "SessionsClient",
    "SetAgentRequest",
    "SetSuggestionFeatureConfigOperationMetadata",
    "SetSuggestionFeatureConfigRequest",
    "SmartReplyAnswer",
    "SpeechContext",
    "SpeechModelVariant",
    "SpeechToTextConfig",
    "SpeechWordInfo",
    "SsmlVoiceGender",
    "StreamingAnalyzeContentRequest",
    "StreamingAnalyzeContentResponse",
    "StreamingDetectIntentRequest",
    "StreamingDetectIntentResponse",
    "StreamingRecognitionResult",
    "SubAgent",
    "SuggestArticlesRequest",
    "SuggestArticlesResponse",
    "SuggestConversationSummaryRequest",
    "SuggestConversationSummaryResponse",
    "SuggestFaqAnswersRequest",
    "SuggestFaqAnswersResponse",
    "SuggestSmartRepliesRequest",
    "SuggestSmartRepliesResponse",
    "Suggestion",
    "SuggestionFeature",
    "SuggestionResult",
    "SynthesizeSpeechConfig",
    "TelephonyDtmf",
    "TelephonyDtmfEvents",
    "TextInput",
    "TextToSpeechSettings",
    "TrainAgentRequest",
    "UpdateAnswerRecordRequest",
    "UpdateContextRequest",
    "UpdateConversationProfileRequest",
    "UpdateDocumentRequest",
    "UpdateEntityTypeRequest",
    "UpdateEnvironmentRequest",
    "UpdateFulfillmentRequest",
    "UpdateIntentRequest",
    "UpdateKnowledgeBaseRequest",
    "UpdateParticipantRequest",
    "UpdateSessionEntityTypeRequest",
    "UpdateVersionRequest",
    "ValidationError",
    "ValidationResult",
    "Version",
    "VersionsClient",
    "VoiceSelectionParams",
    "WebhookRequest",
    "WebhookResponse",
)
